#!/usr/bin/python3

import json
import requests
from charmhelpers.core.hookenv import (
    config,
    log,
)

from charmhelpers.core import unitdata


def get_admin_password():
    kv = unitdata.kv()
    if kv.get('grafana.admin_password'):
        # print('Admin password: {}'.format(kv.get('grafana.admin_password')))
        passwd = kv.get('grafana.admin_password')
    elif config('admin_password'):
        passwd = config('admin_password')
        # print('Admin password: {}'.format(config('admin_password')))
    else:
        log("Password not found!")
        passwd = None

    return passwd


def import_dashboard(dashboard, name=None):
    if name is None:
        name = dashboard['dashboard'].get('title') or 'Untitled'
    headers = {'Content-Type': 'application/json'}
    import_url = 'http://localhost:{}/api/dashboards/db'.format(
                  config('port'))
    passwd = get_admin_password()
    if passwd is None:
        return (False, 'Unable to retrieve grafana password.')
    api_auth = ('admin', passwd)
    r = requests.post(import_url, auth=api_auth, headers=headers,
                      data=json.dumps(dashboard))
    if r.status_code == 200:
        return (True, None)
    else:
        return (False, 'Error importing dashboard "{}": {}'.format(name,
                                                                   r.text))
